@@ -15,6 +15,6 @@ def GetCharacter(search: str, baseUrl: str) -> AnilistCharacter:
         raise AniListException("Status code isn't 200")
     r = req.json()
     try:
-        return AnilistCharacter(**r)
+        return AnilistCharacter.from_dict(r)
     except BaseException as e:
         raise AniListException("{}".format(e))
