@@ -16,6 +16,6 @@ def GetMedia(search: str, baseUrl: str) -> AnilistMedia:
         raise AniListException("Status code isn't 200")
     r = req.json()
     try:
-        return AnilistMedia(**r)
+        return AnilistMedia.from_dict(r)
     except BaseException as e:
         raise AniListException("{}".format(e))
\ No newline at end of file
