@@ -1,47 +1,9 @@
 # The contents of this file is free and unencumbered software released into the
 # public domain. For more information, please refer to <http://unlicense.org/>
 
+from anilistWrapPY.utils.utils import from_int, from_list, from_none, from_str, from_union, to_class
 from dataclasses import dataclass
-from typing import Optional, Any, List, TypeVar, Callable, Type, cast
-
-
-T = TypeVar("T")
-
-
-def from_int(x: Any) -> int:
-    assert isinstance(x, int) and not isinstance(x, bool)
-    return x
-
-
-def from_none(x: Any) -> Any:
-    assert x is None
-    return x
-
-
-def from_union(fs, x):
-    for f in fs:
-        try:
-            return f(x)
-        except:
-            pass
-    assert False
-
-
-def from_str(x: Any) -> str:
-    assert isinstance(x, str)
-    return x
-
-
-def from_list(f: Callable[[Any], T], x: Any) -> List[T]:
-    assert isinstance(x, list)
-    return [f(y) for y in x]
-
-
-def to_class(c: Type[T], x: Any) -> dict:
-    assert isinstance(x, c)
-    return cast(Any, x).to_dict()
-
-
+from typing import Optional, Any, List
 @dataclass
 class Location:
     line: Optional[int] = None
@@ -99,11 +61,3 @@ class AniListError:
                         "errors": from_union([lambda x: from_list(lambda x: to_class(Error, x), x), from_none],
                                              self.errors)}
         return result
-
-
-def ani_list_error_from_dict(s: Any) -> AniListError:
-    return AniListError.from_dict(s)
-
-
-def ani_list_error_to_dict(x: AniListError) -> Any:
-    return to_class(AniListError, x)
